| flags | R Documentation |
The md4c library supports a number of markdown
variants / options. The parsing of these is controlled by flags passed to the
parser. The following functions provide commonly used utilities for these flags.
flags_available()
flags_describe()
flags_used(md)
md |
Markdown ast object |
flags_available() returns a character vector of available flags accepted by parse_md().
flags_describe() returns a tibble with columns flag and description describing each flag.
flags_used() returns a character vector of flags used in a parsed markdown document.
flags_available()
flags_describe()
md_file = system.file("examples/commonmark.md", package = "md4r")
md = parse_md(md_file)
flags_used(md)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.